@@ -49,8 +49,12 @@
 #include "pbd/tokenizer.h"
 
 #include "ardour/utils.h"
+#include "ardour/rc_configuration.h"
 
+#include "ardour_message.h"
+#include "plugin_scan_dialog.h"
 #include "plugin_selector.h"
+#include "ardour_ui.h"
 #include "plugin_utils.h"
 #include "gui_thread.h"
 #include "ui_config.h"
@@ -67,7 +71,7 @@ using namespace ARDOUR_PLUGIN_UTILS;
 static const uint32_t MAX_CREATOR_LEN = 24;
 
 PluginSelector::PluginSelector (PluginManager& mgr)
-	: ArdourDialog (_("Plugin Manager"), true, false)
+	: ArdourDialog (_("Plugin Selector"), true, false)
 	, search_clear_button (Stock::CLEAR)
 	, manager (mgr)
 	, _need_tag_save (false)
@@ -90,12 +94,7 @@ PluginSelector::PluginSelector (PluginManager& mgr)
 
 	plugin_model = Gtk::ListStore::create (plugin_columns);
 	plugin_display.set_model (plugin_model);
-	/* XXX translators: try to convert "Fav" into a short term
-	 * related to "favorite" and "Hid" into a short term
-	 * related to "hidden"
-	 */
-	plugin_display.append_column (_("Fav"), plugin_columns.favorite);
-	plugin_display.append_column (_("Hide"), plugin_columns.hidden);
+	plugin_display.append_column (S_("Favorite|Fav"), plugin_columns.favorite);
 	plugin_display.append_column (_("Name"), plugin_columns.name);
 	plugin_display.append_column (_("Tags"), plugin_columns.tags);
 	plugin_display.append_column (_("Creator"), plugin_columns.creator);
@@ -118,14 +117,8 @@ PluginSelector::PluginSelector (PluginManager& mgr)
 
 	CellRendererToggle* fav_cell = dynamic_cast<CellRendererToggle*>(plugin_display.get_column_cell_renderer (0));
 	fav_cell->property_activatable() = true;
-	fav_cell->property_radio() = true;
 	fav_cell->signal_toggled().connect (sigc::mem_fun (*this, &PluginSelector::favorite_changed));
 
-	CellRendererToggle* hidden_cell = dynamic_cast<CellRendererToggle*>(plugin_display.get_column_cell_renderer (1));
-	hidden_cell->property_activatable() = true;
-	hidden_cell->property_radio() = true;
-	hidden_cell->signal_toggled().connect (sigc::mem_fun (*this, &PluginSelector::hidden_changed));
-
 	scroller.set_border_width(10);
 	scroller.set_policy(Gtk::POLICY_AUTOMATIC, Gtk::POLICY_AUTOMATIC);
 	scroller.add(plugin_display);
@@ -549,7 +542,6 @@ PluginSelector::refiller (const PluginInfoList& plugs, const::std::string& searc
 
 			PluginManager::PluginStatusType status = manager.get_status (*i);
 			newrow[plugin_columns.favorite] = status == PluginManager::Favorite;
-			newrow[plugin_columns.hidden] = status == PluginManager::Hidden;
 
 			string name = (*i)->name;
 			if (name.length() > 48) {
@@ -865,7 +857,6 @@ PluginSelector::plugin_status_changed (PluginType t, std::string uid, PluginMana
 		PluginInfoPtr pp = (*i)[plugin_columns.plugin];
 		if ((pp->type == t) && (pp->unique_id == uid)) {
 			(*i)[plugin_columns.favorite] = (stat == PluginManager::Favorite) ? true : false;
-			(*i)[plugin_columns.hidden] = (stat == PluginManager::Hidden) ? true : false;
 
 			/* if plug was hidden, remove it from the view */
 			if (stat == PluginManager::Hidden || stat == PluginManager::Concealed) {
@@ -964,7 +955,7 @@ PluginSelector::build_plugin_menu ()
 	Gtk::Menu* favs = create_favs_menu(all_plugs);
 	items.push_back (MenuElem (_("Favorites"), *manage (favs)));
 
-	items.push_back (MenuElem (_("Plugin Manager..."), sigc::mem_fun (*this, &PluginSelector::show_manager)));
+	items.push_back (MenuElem (_("Plugin Selector..."), sigc::mem_fun (*this, &PluginSelector::show_manager)));
 	items.push_back (SeparatorElem ());
 
 	Menu* charts = create_charts_menu(all_plugs);
@@ -1188,41 +1179,46 @@ PluginSelector::favorite_changed (const std::string& path)
 	in_row_change = false;
 }
 
-void
-PluginSelector::hidden_changed (const std::string& path)
-{
-	PluginInfoPtr pi;
-
-	if (in_row_change) {
-		return;
-	}
-
-	in_row_change = true;
-
-	TreeModel::iterator iter = plugin_model->get_iter (path);
-
-	if (iter) {
-
-		bool hidden = !(*iter)[plugin_columns.hidden];
-
-		/* change state */
-
-		PluginManager::PluginStatusType status = (hidden ? PluginManager::Hidden : PluginManager::Normal);
-
-		/* save new statuses list */
-
-		pi = (*iter)[plugin_columns.plugin];
-
-		manager.set_status (pi->type, pi->unique_id, status);
-
-		_need_status_save = true;
-	}
-	in_row_change = false;
-}
-
 void
 PluginSelector::show_manager ()
 {
+	bool scan_now = false;
+	if (!manager.cache_valid ()) {
+		ArdourMessageDialog q (
+#ifdef __APPLE__
+				_("Scan VST2/3 and AudioUnit plugins now?")
+#else
+				_("Scan VST2/3 Plugins now?")
+#endif
+				, false, MESSAGE_QUESTION, BUTTONS_YES_NO);
+
+		q.set_title (string_compose (_("Discover %1 Plugins?"),
+#ifdef __APPLE__
+					_("VST/AU")
+#else
+					_("VST")
+#endif
+					));
+
+		q.set_secondary_text (string_compose (_("Third party plugins have not yet been indexed. %1 plugins have to be scanned before they can be used. This can also be done manually from Window > Plugin Manager. Depending on the number of installed plugins the process can take several minutes."),
+#ifdef __APPLE__
+					_("AudioUnit and VST")
+#else
+					_("VST")
+#endif
+					));
+
+		if (q.run () == RESPONSE_YES) {
+			scan_now = true;
+		}
+	}
+
+	if (scan_now) {
+		PluginScanDialog psd (false, true);
+		psd.start ();
+		ARDOUR_UI::instance()->show_plugin_manager ();
+	}
+
 	show_all();
 	run ();
 }
